pub struct TerrainRenderer {
pub pos_to_tile: HashMap<ChunkPos, usize>,
pub tiles: Vec<TerrainRenderTile>,
pub dirty: Vec<Option<(ChunkPos, u32, u32, Vec<u8>)>>,
}Expand description
Holds the tiles used for rendering. Note that all tiles are not necessarily rendered.
Fields
pos_to_tile: HashMap<ChunkPos, usize>Pointer from tile position (x, z) to the corresponding tile datas
tiles: Vec<TerrainRenderTile>A list of terrain render tiles that make up the entire terrain.
dirty: Vec<Option<(ChunkPos, u32, u32, Vec<u8>)>>Implementations
Sourceimpl TerrainRenderer
impl TerrainRenderer
Sourcepub fn new(asset_server: &AssetServer) -> Self
pub fn new(asset_server: &AssetServer) -> Self
Initializes the terrain renderer by creating the heightmap and splat map textures for each tile, and setting up the mapping from tile positions to their corresponding data.
Arguments
asset_server- The Bevy asset server used to create the texture assets for the heightmaps and splat maps.
Returns
A TerrainRenderer component containing the initialized terrain render tiles with their respective heightmap and splat map textures, as well as the mapping from tile positions to their data.
Sourcepub fn extract_dirty(
renderer: Query<'_, '_, &mut TerrainRenderer>,
terrain: Query<'_, '_, &mut Terrain>,
)
pub fn extract_dirty( renderer: Query<'_, '_, &mut TerrainRenderer>, terrain: Query<'_, '_, &mut Terrain>, )
Extracts the dirty tiles from the main terrain